@@ -379,7 +379,8 @@ plymouth_quit_with_transition (GdmSimpleSlave *slave)
         GError  *error;
 
         error = NULL;
-        res = g_spawn_command_line_async ("/bin/plymouth quit --retain-splash", &error);
+        res = g_spawn_command_line_sync ("/bin/plymouth quit --retain-splash",
+                                         NULL, NULL, NULL, &error);
         if (! res) {
                 g_warning ("Could not quit plymouth: %s", error->message);
                 g_error_free (error);
@@ -394,7 +395,8 @@ plymouth_quit_without_transition (GdmSimpleSlave *slave)
         GError  *error;
 
         error = NULL;
-        res = g_spawn_command_line_async ("/bin/plymouth quit", &error);
+        res = g_spawn_command_line_sync ("/bin/plymouth quit",
+                                         NULL, NULL, NULL, &error);
         if (! res) {
                 g_warning ("Could not quit plymouth: %s", error->message);
                 g_error_free (error);
@@ -406,9 +408,6 @@ plymouth_quit_without_transition (GdmSimpleSlave *slave)
 static void
 setup_server (GdmSimpleSlave *slave)
 {
-        /* Put cursor out of the way on first head */
-        gdm_slave_set_initial_cursor_position (GDM_SLAVE (slave));
-
 #ifdef WITH_PLYMOUTH
         /* Plymouth is waiting for the go-ahead to exit */
         if (slave->priv->plymouth_is_running) {
